@@ -525,11 +525,9 @@ class Quantum_Composers:
         if bool(ch) == True:  # specified channel
             for __ch in ch:
                 self.dev.write(':Pulse{}:CMODe NORMal'.format(__ch))
-                self.wcount(__ch,0)
         else:
             for __ch in range(1,9):  # all channels
                 self.dev.write(':Pulse{}:CMODe NORMal'.format(__ch))
-                self.wcount(__ch,0)
     @sleep_method            
     def wid(self,ch,w):
         self.dev.write(':PULSE{}:WIDth {}'.format(ch,w))
@@ -722,7 +720,6 @@ class Quantum_Composers:
     def burst(self, ch, n_pulses):
         self.lev(ch)
         self.pol(ch,'NORM')
-        self.norm(ch)
         self.on(ch)
         self.trigOff()
         self.dev.write(':PULSe{}:CMOD BURS'.format(ch))
